from dataclasses import asdict, astuple, dataclass
from pprint import pprint

from stdl import fs


class Dathas:

    def __init__(self) -> None:
        ...

    @property
    def dict(self) -> dict:
        return asdict(self)

    @property
    def tuple(self) -> tuple:
        return astuple(self)

    def print(self):
        pprint(self.dict)

    @classmethod
    def from_dict(cls, d):
        return cls(**d)

    @classmethod
    def from_json(cls, path: str):
        return cls.from_dict(fs.json_load(path))

    @classmethod
    def from_yaml(cls, path: str):
        return cls.from_dict(fs.yaml_load(path))



import pathlib

from setuptools import find_packages, setup

HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()
REQUIREMENTS = (HERE / "requirements.txt").read_text()

setup(name="dathas",
      version="0.0.3",
      description=" Enhance your Python dataclasses",
      long_description=README,
      long_description_content_type="text/markdown",
      author="Ziga Ivansek",
      author_email="ziga.ivansek@gmail.com",
      url="https://github.com/zigai/dathas",
      license="MIT",
      classifiers=[
          "Programming Language :: Python",
          "Programming Language :: Python :: 3.8",
          "Programming Language :: Python :: 3.9",
          "Programming Language :: Python :: 3.10",
          "Programming Language :: Python :: 3 :: Only",
          "Topic :: Software Development :: Libraries :: Python Modules",
      ],
      package_dir={"": "dathas"},
      py_modules=["dathas"],
      install_requires=REQUIREMENTS)
